pub struct StatsExporter { /* private fields */ }Expand description
An exporter that concentrates and sends stats to the agent
Implementations
Sourceimpl StatsExporter
impl StatsExporter
Sourcepub fn new(
flush_interval: Duration,
concentrator: Arc<Mutex<SpanConcentrator>>,
meta: TracerMetadata,
endpoint: Endpoint,
cancellation_token: CancellationToken,
client: HttpClient,
) -> Self
pub fn new( flush_interval: Duration, concentrator: Arc<Mutex<SpanConcentrator>>, meta: TracerMetadata, endpoint: Endpoint, cancellation_token: CancellationToken, client: HttpClient, ) -> Self
Return a new StatsExporter
flush_intervalthe interval on which the concentrator is flushedconcentratorSpanConcentrator storing the stats to be sent to the agentmetametadata used in ClientStatsPayload and as headers to send stats to the agentendpointthe Endpoint used to send stats to the agentcancellation_tokenToken used to safely shutdown the exporter by force flushing the concentrator
Sourcepub async fn send(&self, force_flush: bool) -> Result<()>
pub async fn send(&self, force_flush: bool) -> Result<()>
Flush the stats stored in the concentrator and send them
If the stats flushed from the concentrator contain at least one time bucket the stats are
sent to self.endpoint. The stats are serialized as msgpack.
Errors
The function will return an error in the following case:
- The endpoint failed to build
- The stats payload cannot be serialized as a valid http body
- The http client failed while sending the request
- The http status of the response is not 2xx
Panic
Will panic if another thread panicked while holding the concentrator lock in which case stats cannot be flushed since the concentrator might be corrupted.