TraceExporter provides a minimum viable product (MVP) to send traces to agents. The aim of the project at this state is to provide a basic API in order to test its viability and integration in different languages.
Modules
- agent_
info - Provides utilities to get config from the /info endpoint of an agent
- stats_
exporter - trace_
exporter